aboutsummaryrefslogtreecommitdiffstats
path: root/vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php')
-rw-r--r--vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php b/vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php
index 25b54a834..5aa0e8865 100644
--- a/vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php
+++ b/vendor/ramsey/uuid/src/Generator/RandomLibAdapter.php
@@ -19,9 +19,9 @@ use RandomLib\Factory;
/**
* RandomLibAdapter provides functionality to generate strings of random
- * binary data using the ircmaxell/random-lib library
+ * binary data using the paragonie/random-lib library
*
- * @link https://packagist.org/packages/ircmaxell/random-lib
+ * @link https://packagist.org/packages/paragonie/random-lib
*/
class RandomLibAdapter implements RandomGeneratorInterface
{
@@ -33,10 +33,10 @@ class RandomLibAdapter implements RandomGeneratorInterface
/**
* Constructs a `RandomLibAdapter` using a `RandomLib\Generator`
*
* By default, if no `Generator` is passed in, this creates a medium-strength
* generator to use when generating random binary data.
*
- * @param Generator $generator An ircmaxell/random-lib `Generator`
+ * @param Generator $generator An paragonie/random-lib `Generator`
*/
public function __construct(Generator $generator = null)
{
@@ -45,7 +45,7 @@ class RandomLibAdapter implements RandomGeneratorInterface
if ($this->generator === null) {
$factory = new Factory();
- $this->generator = $factory->getMediumStrengthGenerator();
+ $this->generator = $factory->getHighStrengthGenerator();
}
}
@@ -33,10 +33,10 @@ class RandomLibAdapter implements RandomGeneratorInterface
* Constructs a `RandomLibAdapter` using a `RandomLib\Generator`
*
- * By default, if no `Generator` is passed in, this creates a medium-strength
+ * By default, if no `Generator` is passed in, this creates a high-strength
* generator to use when generating random binary data.
*